Changes
~~~~~~~

v0.2 (2012-05-25)
_________________

- integrate MediaElement.js audio player to default templates
- display file type and size in download button
- serve m3u playlist

v0.1.1 (2012-05-19)
___________________


- add other user's tracks listing
- update repository URL
        
v0.1 (2012-02-21)
_________________

Initial release.
